@@ -23,18 +23,17 @@
 #include <linux/kd.h>
 #include <endian.h>
 #include <sysexits.h>
+
+#include <kbdfile.h>
+
+#include "libcommon.h"
+
 #include "paths.h"
-#include "getfd.h"
-#include "findfile.h"
 #include "loadunimap.h"
 #include "psf.h"
 #include "psffontop.h"
 #include "kdfontop.h"
 #include "kdmapop.h"
-#include "xmalloc.h"
-#include "nls.h"
-#include "version.h"
-#include "kbd_error.h"
 
 static int position_codepage(int iunit);
 static void saveoldfont(int fd, char *ofil);
@@ -60,15 +59,15 @@ const char *const partfontdirpath[]  = { "", DATADIR "/" FONTDIR "/" PARTIALDIR
 const char *const partfontsuffixes[] = { "", 0 };
 
 static inline int
-findfont(char *fnam, lkfile_t *fp)
+findfont(char *fnam, struct kbdfile *fp)
 {
-	return lk_findfile(fnam, fontdirpath, fontsuffixes, fp);
+	return kbdfile_find(fnam, fontdirpath, fontsuffixes, fp);
 }
 
 static inline int
-findpartialfont(char *fnam, lkfile_t *fp)
+findpartialfont(char *fnam, struct kbdfile *fp)
 {
-	return lk_findfile(fnam, partfontdirpath, partfontsuffixes, fp);
+	return kbdfile_find(fnam, partfontdirpath, partfontsuffixes, fp);
 }
 
 static void __attribute__((noreturn))
@@ -112,10 +111,7 @@ int main(int argc, char *argv[])
 	int restore = 0;
 
 	set_progname(argv[0]);
-
-	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE_NAME, LOCALEDIR);
-	textdomain(PACKAGE_NAME);
+	setuplocale();
 
 	ifiles[0] = mfil = ufil = Ofil = ofil = omfil = oufil = NULL;
 	iunit = hwunit = 0;
@@ -291,19 +287,19 @@ do_loadfont(int fd, char *inbuf, int width, int height, int hwunit,
 		if (bad_video_erase_char) {
 			fprintf(stderr,
 			        _("%s: font position 32 is nonblank\n"),
-			        progname);
+			        get_progname());
 			switch (erase_mode) {
 				case 3:
 					exit(EX_DATAERR);
 				case 2:
 					for (i                          = 0; i < kcharsize; i++)
 						buf[32 * kcharsize + i] = 0;
-					fprintf(stderr, _("%s: wiped it\n"), progname);
+					fprintf(stderr, _("%s: wiped it\n"), get_progname());
 					break;
 				case 1:
 					fprintf(stderr,
 					        _("%s: background will look funny\n"),
-					        progname);
+					        get_progname());
 			}
 			fflush(stderr);
 			sleep(2);
@@ -378,7 +374,7 @@ do_loadtable(int fd, struct unicode_list *uclistheads, int fontsize)
 	}
 	if (ct != maxct) {
 		char *u = _("%s: bug in do_loadtable\n");
-		fprintf(stderr, u, progname);
+		fprintf(stderr, u, get_progname());
 		exit(EX_SOFTWARE);
 	}
 
@@ -400,13 +396,16 @@ loadnewfonts(int fd, char **ifiles, int ifilct,
 	int bigfontbuflth, bigfontsize, bigheight, bigwidth;
 	struct unicode_list *uclistheads;
 	int i;
-	lkfile_t fp;
+	struct kbdfile *fp;
 
 	if (ifilct == 1) {
 		loadnewfont(fd, ifiles[0], iunit, hwunit, no_m, no_u);
 		return;
 	}
 
+	if ((fp = kbdfile_new(NULL)) == NULL)
+		nomem();
+
 	/* several fonts that must be merged */
 	/* We just concatenate the bitmaps - only allow psf fonts */
 	bigfontbuf    = NULL;
@@ -418,7 +417,7 @@ loadnewfonts(int fd, char **ifiles, int ifilct,
 
 	for (i = 0; i < ifilct; i++) {
 		ifil = ifiles[i];
-		if (findfont(ifil, &fp) && findpartialfont(ifil, &fp)) {
+		if (findfont(ifil, fp) && findpartialfont(ifil, fp)) {
 			fprintf(stderr, _("Cannot open font file %s\n"), ifil);
 			exit(EX_NOINPUT);
 		}
@@ -427,21 +426,24 @@ loadnewfonts(int fd, char **ifiles, int ifilct,
 		inputlth = fontbuflth = 0;
 		fontsize              = 0;
 
-		if (readpsffont(fp.fd, &inbuf, &inputlth, &fontbuf, &fontbuflth,
+		if (readpsffont(kbdfile_get_file(fp), &inbuf, &inputlth, &fontbuf, &fontbuflth,
 		                &width, &fontsize, bigfontsize,
 		                no_u ? NULL : &uclistheads)) {
 			fprintf(stderr, _("When loading several fonts, all "
 			                  "must be psf fonts - %s isn't\n"),
-			        fp.pathname);
-			lk_fpclose(&fp);
+			        kbdfile_get_pathname(fp));
+			kbdfile_free(fp);
 			exit(EX_DATAERR);
 		}
-		lk_fpclose(&fp); // avoid zombies, jw@suse.de (#88501)
+
+		kbdfile_free(fp); // avoid zombies, jw@suse.de (#88501)
+
 		bytewidth = (width + 7) / 8;
 		height    = fontbuflth / (bytewidth * fontsize);
+
 		if (verbose)
 			printf(_("Read %d-char %dx%d font from file %s\n"),
-			       fontsize, width, height, fp.pathname);
+			       fontsize, width, height, kbdfile_get_pathname(fp));
 
 		if (bigheight == 0)
 			bigheight = height;
@@ -475,13 +477,17 @@ loadnewfonts(int fd, char **ifiles, int ifilct,
 static void
 loadnewfont(int fd, char *ifil, int iunit, int hwunit, int no_m, int no_u)
 {
-	lkfile_t fp;
+	struct kbdfile *fp;
+
 	char defname[20];
 	int height, width, bytewidth, def = 0;
 	char *inbuf, *fontbuf;
 	int inputlth, fontbuflth, fontsize, offset;
 	struct unicode_list *uclistheads;
 
+	if ((fp = kbdfile_new(NULL)) == NULL)
+		nomem();
+
 	if (!*ifil) {
 		/* try to find some default file */
 
@@ -490,23 +496,23 @@ loadnewfont(int fd, char *ifil, int iunit, int hwunit, int no_m, int no_u)
 		if (iunit < 0 || iunit > 32)
 			iunit = 0;
 		if (iunit == 0) {
-			if (findfont(ifil = "default", &fp) &&
-			    findfont(ifil = "default8x16", &fp) &&
-			    findfont(ifil = "default8x14", &fp) &&
-			    findfont(ifil = "default8x8", &fp)) {
+			if (findfont(ifil = "default", fp) &&
+			    findfont(ifil = "default8x16", fp) &&
+			    findfont(ifil = "default8x14", fp) &&
+			    findfont(ifil = "default8x8", fp)) {
 				fprintf(stderr, _("Cannot find default font\n"));
 				exit(EX_NOINPUT);
 			}
 		} else {
 			sprintf(defname, "default8x%d", iunit);
-			if (findfont(ifil = defname, &fp) &&
-			    findfont(ifil = "default", &fp)) {
+			if (findfont(ifil = defname, fp) &&
+			    findfont(ifil = "default", fp)) {
 				fprintf(stderr, _("Cannot find %s font\n"), ifil);
 				exit(EX_NOINPUT);
 			}
 		}
 	} else {
-		if (findfont(ifil, &fp)) {
+		if (findfont(ifil, fp)) {
 			fprintf(stderr, _("Cannot open font file %s\n"), ifil);
 			exit(EX_NOINPUT);
 		}
@@ -519,16 +525,17 @@ loadnewfont(int fd, char *ifil, int iunit, int hwunit, int no_m, int no_u)
 	inputlth = fontbuflth = fontsize = 0;
 	width                            = 8;
 	uclistheads                      = NULL;
-	if (readpsffont(fp.fd, &inbuf, &inputlth, &fontbuf, &fontbuflth,
+	if (readpsffont(kbdfile_get_file(fp), &inbuf, &inputlth, &fontbuf, &fontbuflth,
 	                &width, &fontsize, 0,
 	                no_u ? NULL : &uclistheads) == 0) {
-		lk_fpclose(&fp);
+		kbdfile_free(fp);
+
 		/* we've got a psf font */
 		bytewidth = (width + 7) / 8;
 		height    = fontbuflth / (bytewidth * fontsize);
 
 		do_loadfont(fd, fontbuf, width, height, hwunit,
-		            fontsize, fp.pathname);
+		            fontsize, kbdfile_get_pathname(fp));
 		if (uclistheads && !no_u)
 			do_loadtable(fd, uclistheads, fontsize);
 #if 1
@@ -537,7 +544,7 @@ loadnewfont(int fd, char *ifil, int iunit, int hwunit, int no_m, int no_u)
 #endif
 		return;
 	}
-	lk_fpclose(&fp); // avoid zombies, jw@suse.de (#88501)
+	kbdfile_free(fp); // avoid zombies, jw@suse.de (#88501)
 
 	/* instructions to combine fonts? */
 	{
@@ -609,7 +616,7 @@ loadnewfont(int fd, char *ifil, int iunit, int hwunit, int no_m, int no_u)
 		height   = inputlth / 256;
 	}
 	do_loadfont(fd, inbuf + offset, width, height, hwunit, fontsize,
-	            fp.pathname);
+	            kbdfile_get_pathname(fp));
 }
 
 static int
@@ -741,7 +748,7 @@ saveoldfontplusunicodemap(int fd, char *Ofil)
 /* For the moment: only the current console, only the G0 set */
 
 static void
-send_escseq(int fd, char *seq, int n)
+send_escseq(int fd, const char *seq, int n)
 {
 	if (write(fd, seq, n) != n) /* maybe fd is read-only */
 		printf("%s", seq);
